﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using DlhSoft.Windows.Data;

namespace TaskListViewAssignmentsSample
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : Window
    {
        public Window1()
        {
            InitializeComponent();
        }

        // Determines when the new assignment command can be executed.
        private void NewCommandBinding_CanExecute(object sender, CanExecuteRoutedEventArgs e)
        {
            Task managedTask = TaskListView != null ? TaskListView.SelectedTask : null;
            TaskItem taskItem = TaskListView != null ? TaskListView.SelectedItem as TaskItem : null;
            ResourceItem resourceItem = ResourceComboBox != null ? ResourceComboBox.SelectedItem as ResourceItem : null;
            if (resourceItem != null && ResourceComboBox.Text != resourceItem.Content as string)
                resourceItem = null;
            e.CanExecute = taskItem != null && !managedTask.HasChildren && (resourceItem != null || !string.IsNullOrEmpty(ResourceComboBox.Text)) && (resourceItem == null || !taskItem.Assignments.Any(a => a.ResourceItem == resourceItem));
            e.Handled = true;
        }

        // Executes the new assignment command.
        private void NewCommandBinding_Executed(object sender, ExecutedRoutedEventArgs e)
        {
            TaskItem taskItem = TaskListView.SelectedItem as TaskItem;
            ResourceItem resourceItem = ResourceComboBox.SelectedItem as ResourceItem;
            if (resourceItem != null && ResourceComboBox.Text != resourceItem.Content as string)
                resourceItem = null;
            if (resourceItem == null)
                resourceItem = new ResourceItem { Content = ResourceComboBox.Text };
            taskItem.Assignments.Add(new AssignmentItem { ResourceItem = resourceItem });
            ResourceComboBox.SelectedItem = resourceItem;
            e.Handled = true;
        }

        // Determines when the delete assignment command can be executed.
        private void DeleteCommandBinding_CanExecute(object sender, CanExecuteRoutedEventArgs e)
        {
            e.CanExecute = AssignmentListView != null && AssignmentListView.SelectedItems.Count > 0;
            e.Handled = true;
        }

        // Executes the delete assignment command.
        private void DeleteCommandBinding_Executed(object sender, ExecutedRoutedEventArgs e)
        {
            TaskItem taskItem = TaskListView.SelectedItem as TaskItem;
            List<AssignmentItem> assignmentItems = new List<AssignmentItem>();
            foreach (Assignment managedAssignment in AssignmentListView.SelectedItems)
                assignmentItems.Add(managedAssignment.Item as AssignmentItem);
            foreach (AssignmentItem assignmentItem in assignmentItems)
                taskItem.Assignments.Remove(assignmentItem);
            e.Handled = true;
        }
    }
}
